@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2005-2007  QRW Software
+--                 Copyright (C) 2005-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,9 @@
 --
 --
 -- $Log: address.c,v $
+-- Revision 1.15  2009/03/07 20:17:19  jsedwards
+-- Removed #include of objectify_private.h, not needed.
+--
 -- Revision 1.14  2007/07/01 19:44:11  jsedwards
 -- Upgrade to GPLv3.
 --
@@ -95,7 +98,6 @@
 
 #include "crc32.h"
 #include "objectify.h"
-#include "objectify_private.h"
 
 
 bool nwos_find_state_postal_code(char* state_postal_code, ObjRef* ref)
