@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2007-2008  QRW Software
+--                 Copyright (C) 2007-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -29,6 +29,13 @@
 -- This is a one time use program to add a new revision to the File class.
 --
 -- $Log: add_class_revision.c,v $
+-- Revision 1.9  2009/03/08 19:38:10  jsedwards
+-- Fixed year in Copyright.
+--
+-- Revision 1.8  2009/03/08 17:00:01  jsedwards
+-- Changed objectify_private.h to objectify.h and added include include
+-- class_definition.h.
+--
 -- Revision 1.7  2008/09/01 00:22:50  jsedwards
 -- Fix year in copyright.  NO code changes.
 --
@@ -67,7 +74,8 @@
 #include <unistd.h>
 
 #include "../crc32.h"
-#include "../objectify_private.h"
+#include "../class_definition.h"     /* define nwos_public_class_definition_class_ref */
+#include "../objectify.h"
 
 
 static size_t get_class_object_size(void* class_obj)
