@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                   Copyright (C) 2007  QRW Software
+--                 Copyright (C) 2007-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,13 @@
 --
 --
 -- $Log: add_credit_union.c,v $
+-- Revision 1.10  2008/09/01 00:22:51  jsedwards
+-- Fix year in copyright.  NO code changes.
+--
+-- Revision 1.9  2008/08/31 16:24:44  jsedwards
+-- Added assert around call to nwos_read_object_from_disk because now it
+-- returns false if it fails, before it asserted itself if it failed.
+--
 -- Revision 1.8  2007/07/01 19:44:12  jsedwards
 -- Upgrade to GPLv3.
 --
@@ -193,7 +200,7 @@ int main(int argc, char* argv[])
 	printf("Object created: %02x%02x%02x%02x\n", reference.id[0], reference.id[1], reference.id[2], reference.id[3]);
     }
 
-    nwos_read_object_from_disk(&reference, &test_cu_obj, sizeof(test_cu_obj));
+    assert(nwos_read_object_from_disk(&reference, &test_cu_obj, sizeof(test_cu_obj)));
 
     if (memcmp(&test_cu_obj, &cu_obj, sizeof(cu_obj)) != 0)
     {
