@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2007-2008  QRW Software
+--                 Copyright (C) 2007-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,15 @@
 --
 --
 -- $Log: backup.c,v $
+-- Revision 1.24  2009/03/14 22:41:59  jsedwards
+-- Added include of new backup.h file.
+--
+-- Revision 1.23  2009/03/13 12:09:28  jsedwards
+-- Added include log.h file.
+--
+-- Revision 1.22  2009/03/08 00:06:18  jsedwards
+-- Changed include objectify_private.h to disk_io.h.
+--
 -- Revision 1.21  2008/06/26 14:51:33  jsedwards
 -- Changed nwos_initialize_backup to return false if opening backup files
 -- failed.
@@ -120,7 +129,9 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#include "objectify_private.h"
+#include "backup.h"
+#include "disk_io.h"
+#include "log.h"
 #include "time_stamp.h"
 
 
