@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2006-2008  QRW Software
+--                 Copyright (C) 2006-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,18 @@
 --
 --
 -- $Log: check_block_maps.c,v $
+-- Revision 1.24  2009/03/14 23:14:04  jsedwards
+-- Added include of the new chunk_info.h file.
+--
+-- Revision 1.23  2009/03/14 11:46:07  jsedwards
+-- Added include of user_config.h file.
+--
+-- Revision 1.22  2009/03/13 12:10:26  jsedwards
+-- Added include config.h file.
+--
+-- Revision 1.21  2009/03/08 00:43:49  jsedwards
+-- Changed include objectify_private.h to disk_io.h.
+--
 -- Revision 1.20  2008/08/10 15:23:24  jsedwards
 -- Added path to "Missing magic number" and "Incorrect version in header" error
 -- messages.
@@ -135,7 +147,11 @@
 #include <sys/time.h>
 #include <unistd.h>
 
-#include "objectify_private.h"
+#include "chunk_info.h"
+#include "config.h"
+#include "disk_io.h"
+#include "user_config.h"
+
 
 static void print_usage(char *program)
 {
