@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2006-2008  QRW Software
+--                 Copyright (C) 2006-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,19 @@
 --
 --
 -- $Log: disc_list.c,v $
+-- Revision 1.35  2009/03/19 11:38:21  jsedwards
+-- Wrapped call to nwos_set_security_level with ifdef CHANGE_SECURITY_TO_DENSITY
+-- because what was called security level stuff is temporarily disabled.
+--
+-- Revision 1.34  2009/03/14 03:31:24  jsedwards
+-- Added include of bit_map.h file.
+--
+-- Revision 1.33  2009/03/10 04:04:08  jsedwards
+-- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
+--
+-- Revision 1.32  2009/03/08 00:13:54  jsedwards
+-- Changed include objectify_private.h to objectify.h.
+--
 -- Revision 1.31  2008/09/01 03:13:41  jsedwards
 -- Change for new nwos_initialize_objectify calling convention (doesn't pass
 -- back root_object_reference anymore) and removed call to nwos_set_root_object
@@ -166,7 +179,9 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <time.h>
-#include "objectify_private.h"     /* this is kinda bad, but need overwrite to link old and new revisions */
+
+#include "bit_map.h"
+#include "objectify.h"
 #include "crc32.h"
 
 
@@ -187,7 +202,7 @@ void check_for_previous_version_and_link(ObjRef* new_assoc_ref)
     C_struct_Path_And_File_Association assoc_obj;
     C_struct_Path_And_File_Association old_assoc_obj;
     C_struct_Path_And_File_Association new_assoc_obj;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_PATH_OBJ_SIZE];
     C_struct_File_Path* ptr_path_obj = (C_struct_File_Path*)kludge;
     ReferenceList* ref_list;
     int num_refs;
@@ -439,7 +454,9 @@ int main(int argc, char* argv[])
 
     nwos_initialize_objectify(READ_WRITE, DEFAULT_FILE);
 
+#ifdef CHANGE_SECURITY_TO_DENSITY
     nwos_set_security_level(Security_Very_Low);
+#endif
 
     if (!nwos_check_blocks_available(2 + num_files * 12)) /* 1 file = 14, 2 files = 26, 3 files = 38... */
     {
