@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2006-2008  QRW Software
+--                 Copyright (C) 2006-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,22 @@
 --
 --
 -- $Log: disk_usage.c,v $
+-- Revision 1.37  2009/04/03 13:12:13  jsedwards
+-- Added printing of which archive is being accessed and when it was formatted.
+-- Also increased the width of the block print field from 9 digits to 10 digits.
+--
+-- Revision 1.36  2009/03/14 23:14:04  jsedwards
+-- Added include of the new chunk_info.h file.
+--
+-- Revision 1.35  2009/03/14 11:46:08  jsedwards
+-- Added include of user_config.h file.
+--
+-- Revision 1.34  2009/03/13 12:28:46  jsedwards
+-- Added includes for config.h and progress_bar.h files.
+--
+-- Revision 1.33  2009/03/08 00:06:18  jsedwards
+-- Changed include objectify_private.h to disk_io.h.
+--
 -- Revision 1.32  2008/12/27 14:34:23  jsedwards
 -- Merged from alpha_29_5_branch back into main trunk.
 --
@@ -186,7 +202,12 @@
 #include <sys/time.h>
 #include <unistd.h>
 
-#include "objectify_private.h"
+#include "chunk_info.h"
+#include "config.h"
+#include "disk_io.h"
+#include "progress_bar.h"
+#include "user_config.h"
+
 
 static void print_usage(char *program)
 {
@@ -478,15 +499,28 @@ int main(int argc, char* argv[])
     }
 
     printf("\n");
-    printf("Last change: %u-%02u-%02u %02u:%02u:%02u  version: %c%c%c%c\n",
+
+    printf("Archive: %s\n", obj_file_path);
+
+    printf("Version: %c%c%c%c\n", 
+	   disk_header.version_string[0], disk_header.version_string[1],
+	   disk_header.version_string[2], disk_header.version_string[3]);
+
+    printf("Formatted:   %u-%02u-%02u %02u:%02u:%02u\n",
+	   nwos_extract_year_from_time_stamp(disk_header.last_prep_disk),
+	   nwos_extract_month_from_time_stamp(disk_header.last_prep_disk),
+	   nwos_extract_day_of_month_from_time_stamp(disk_header.last_prep_disk),
+	   nwos_extract_hour_from_time_stamp(disk_header.last_prep_disk),
+	   nwos_extract_minute_from_time_stamp(disk_header.last_prep_disk),
+	   nwos_extract_second_from_time_stamp(disk_header.last_prep_disk));
+
+    printf("Last change: %u-%02u-%02u %02u:%02u:%02u\n",
 	   nwos_extract_year_from_time_stamp(disk_header.last_change),
 	   nwos_extract_month_from_time_stamp(disk_header.last_change),
 	   nwos_extract_day_of_month_from_time_stamp(disk_header.last_change),
 	   nwos_extract_hour_from_time_stamp(disk_header.last_change),
 	   nwos_extract_minute_from_time_stamp(disk_header.last_change),
-	   nwos_extract_second_from_time_stamp(disk_header.last_change),
-	   disk_header.version_string[0], disk_header.version_string[1],
-	   disk_header.version_string[2], disk_header.version_string[3]);
+	   nwos_extract_second_from_time_stamp(disk_header.last_change));
 
     /* get what the disk thinks */
     nwos_4_uint8_to_uint32(disk_header.total_blocks, &reserved_private_blocks);
@@ -561,15 +595,15 @@ int main(int argc, char* argv[])
 
     printf("\n");
 
-    printf("              Chunks   Blocks   %s\n", range);
+    printf("              Chunks   Blocks    %s\n", range);
 
-    printf("System:        %5u  %9u    %5.1f  %5.1f%%\n",
+    printf("System:        %5u  %10u    %5.1f  %5.1f%%\n",
 	   1,
 	   system_blocks,
 	   (float)system_blocks / divisor,
 	   100.0f * (float)system_blocks / (float)total_blocks);
 
-    printf("Unallocated:   %5u  %9u    %5.1f  %5.1f%%\n",
+    printf("Unallocated:   %5u  %10u    %5.1f  %5.1f%%\n",
 	   total_private_chunks - used_private_chunks,
 	   unallocated_blocks,
 	   (float)unallocated_blocks / divisor,
@@ -577,17 +611,17 @@ int main(int argc, char* argv[])
 
     printf("Allocated:     %5u\n", used_private_chunks);
 
-    printf("  Used:               %9u    %5.1f  %5.1f%%\n",
+    printf("  Used:               %10u    %5.1f  %5.1f%%\n",
 	   used_private_blocks,
 	   (float)used_private_blocks / divisor,
 	   100.0f * (float)used_private_blocks / (float)total_blocks);
 
-    printf("  Free:               %9u    %5.1f  %5.1f%%\n",
+    printf("  Free:               %10u    %5.1f  %5.1f%%\n",
 	   allocated_blocks - used_private_blocks,
 	   (float)(allocated_blocks - used_private_blocks) / divisor,
 	   100.0f * (float)(allocated_blocks - used_private_blocks) / (float)total_blocks);
 
-    printf("  Total:              %9u    %5.1f  %5.1f%%\n",
+    printf("  Total:              %10u    %5.1f  %5.1f%%\n",
 	   allocated_blocks,
 	   (float)allocated_blocks / divisor,
 	   100.0f * (float)allocated_blocks / (float)total_blocks);
