@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2006-2008  QRW Software
+--                 Copyright (C) 2006-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,30 @@
 --
 --
 -- $Log: expand_sparse.c,v $
+-- Revision 1.40  2009/03/14 23:06:41  jsedwards
+-- Added include of the new backup.h file.
+--
+-- Revision 1.39  2009/03/14 11:43:21  jsedwards
+-- Added includes for gen_id.h and user_config.h files.
+--
+-- Revision 1.38  2009/03/14 03:31:24  jsedwards
+-- Added include of bit_map.h file.
+--
+-- Revision 1.37  2009/03/13 12:36:58  jsedwards
+-- Added includes for config.h, log.h, and progress_bar.h files.  Also changed
+-- to call nwos_terminate_disk_io instead of nwos_terminate_objectify (because
+-- it calls nwos_initialize_disk_io, not nwos_initialize_objectify).
+--
+-- Revision 1.36  2009/03/08 00:06:18  jsedwards
+-- Changed include objectify_private.h to disk_io.h.
+--
+-- Revision 1.35  2009/03/02 15:36:49  jsedwards
+-- Removed code that incremented total chunks and blocks when expanding file,
+-- that is now done by the write_empty_chunk function.
+--
+-- Revision 1.34  2009/03/02 13:56:48  jsedwards
+-- Add code to expand file if archive is stored in a file (not a block device).
+--
 -- Revision 1.33  2008/09/01 03:15:46  jsedwards
 -- Change to call nwos_initialize_disk_io instead of nwos_initialize_objectify.
 --
@@ -184,8 +208,14 @@
 #include <sys/time.h>
 #include <unistd.h>
 
-#include "objectify_private.h"
-
+#include "backup.h"
+#include "bit_map.h"
+#include "config.h"
+#include "disk_io.h"
+#include "gen_id.h"
+#include "log.h"
+#include "progress_bar.h"
+#include "user_config.h"
 
 
 static void print_usage(char *program)
@@ -338,20 +368,41 @@ int main(int argc, char* argv[])
 
     }
 
-    printf("   total_private_blocks: %u  used_private_blocks: %u\n",
-	   total_private_blocks, used_private_blocks);
-
-    if (used_private_chunks > nwos_total_private_chunks)
+    if (nwos_archive_is_block_device())
     {
-	fprintf(stderr, "used chunks: %u greater than disk space: %u\n",
-		used_private_chunks, nwos_total_private_chunks);
-	exit(1);
+	printf("   total_private_blocks: %u  used_private_blocks: %u\n",
+	       total_private_blocks, used_private_blocks);
+
+	if (used_private_chunks > nwos_total_private_chunks)
+	{
+	    fprintf(stderr, "used chunks: %u greater than disk space: %u\n",
+		    used_private_chunks, nwos_total_private_chunks);
+	    exit(1);
+	}
     }
+    else if (nwos_total_private_chunks < used_private_chunks)
+    {
+	printf("Expanding file...\n");
+
+	nwos_start_progress_bar();
+
+	while (nwos_total_private_chunks < used_private_chunks)
+	{
+	    nwos_update_progress_bar((float)nwos_total_private_chunks / (float)used_private_chunks);
+
+	    nwos_write_empty_chunk(nwos_total_private_chunks);
+	} 
+
+	nwos_finish_progress_bar();
+    }
+
 
     /* finally copy the objects */
 
     bytes_read = fread(block, 1, FILE_BLOCK_SIZE, ifp);
 
+    printf("Writing blocks...\n");
+
     nwos_start_progress_bar();
 
     while (bytes_read == FILE_BLOCK_SIZE)
@@ -408,7 +459,7 @@ int main(int argc, char* argv[])
 	exit(1);
     }
 
-    nwos_terminate_objectify();
+    nwos_terminate_disk_io();
 
     snprintf(msg, sizeof(msg), "Number of blocks written: %d  chunks_used: %u",
 	     num_blocks, nwos_used_private_chunks);
