@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2007-2008  QRW Software
+--                 Copyright (C) 2007-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,17 @@
 --
 --
 -- $Log: financial.c,v $
+-- Revision 1.10  2009/03/10 11:19:00  jsedwards
+-- Moved MAX_NUMBER_SIZE, MAX_ID_SIZE, MAX_ACCOUNT_NUMBER_SIZE, and
+-- MAX_CHECKING_SIZE to the objectify.h file and renamed.
+--
+-- Revision 1.9  2009/03/09 14:12:35  jsedwards
+-- Eliminated use of FILE_BLOCK_SIZE for kludge buffers.
+--
+-- Revision 1.8  2009/03/08 00:50:30  jsedwards
+-- Changed include objectify_private.h to objectify.h and changed to call
+-- nwos_generate_new_id instead of nwos_generate_new_completely_random_id.
+--
 -- Revision 1.7  2008/09/01 00:10:51  jsedwards
 -- Fix copyright year.  NO code changes.
 --
@@ -60,17 +71,15 @@
 #include <string.h>   /* define memset */
 
 #include "crc32.h"
-#include "objectify_private.h"
+#include "objectify.h"
 
 #define MAX_NAME_SIZE 128
-#define MAX_NUMBER_SIZE 18
-#define MAX_ID_SIZE 4
 
 
 static size_t get_account_number_object_size(void* account_num_obj)
 {
     uint8 count = ((C_struct_Account_Number*)account_num_obj)->count;
-    assert(0 < count && count <= MAX_NUMBER_SIZE);
+    assert(0 < count && count <= MAX_ACCOUNT_NUMBER_SIZE);
 
     return sizeof(C_struct_Account_Number) + count;
 }
@@ -79,7 +88,7 @@ static size_t get_account_number_object_size(void* account_num_obj)
 static size_t get_checking_object_size(void* checking_obj)
 {
     uint8 count = ((C_struct_Checking*)checking_obj)->count;
-    assert(0 < count && count <= MAX_ID_SIZE);
+    assert(0 < count && count <= MAX_CHECKING_ID_SIZE);
 
     return sizeof(C_struct_Checking) + count;
 }
@@ -92,7 +101,7 @@ static bool valid_number(char* number)
 
     length = strlen(number);
 
-    assert(length <= MAX_NUMBER_SIZE);
+    assert(length <= MAX_ACCOUNT_NUMBER_SIZE);
 
     for (p  = number; *p != '\0'; p++)
     {
@@ -306,7 +315,7 @@ ObjCreateResult nwos_find_or_create_private_credit_union(char* name, ObjRef* ref
 
 	assert(nwos_read_object_from_disk(&public_cu_ref, &cu_obj, sizeof(cu_obj)));
 
-	nwos_generate_new_completely_random_id(ref);
+	nwos_generate_new_id(ref);
 
 	snprintf(msg, sizeof(msg), "clone_credit_union(%02x%02x%02x%02x) -> %02x%02x%02x%02x\n",
 		 public_cu_ref.id[0], public_cu_ref.id[1], public_cu_ref.id[2], public_cu_ref.id[3],
@@ -340,7 +349,7 @@ bool nwos_find_account_number(char* number, ObjRef* ref)
 {
     ObjRef number_class_ref;
     C_struct_Class_Definition class_def_obj;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_ACCOUNT_NUMBER_OBJ_SIZE];
     C_struct_Account_Number* ptr_number_obj = (C_struct_Account_Number*)kludge;
     ObjRef object_class;
     ReferenceList* ref_list;
@@ -395,7 +404,7 @@ bool nwos_find_account_number(char* number, ObjRef* ref)
 ObjCreateResult nwos_find_or_create_account_number(char* number, ObjRef* ref)
 {
     ObjRef number_class_ref;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_ACCOUNT_NUMBER_OBJ_SIZE];
     C_struct_Account_Number* ptr_number_obj = (C_struct_Account_Number*)kludge;
     size_t length;
     ObjCreateResult result = FOUND_EXISTING;
@@ -448,7 +457,7 @@ ObjCreateResult nwos_find_or_create_account_number(char* number, ObjRef* ref)
 
 void nwos_account_number_to_string(ObjRef* ref, char* string, size_t size)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_ACCOUNT_NUMBER_OBJ_SIZE];
     C_struct_Account_Number* ptr_number_obj = (C_struct_Account_Number*)kludge;
 
     assert(nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), &get_account_number_object_size));
@@ -550,7 +559,7 @@ void nwos_create_account(ObjRef* credit_union_ref, ObjRef* account_num_ref, ObjR
 void nwos_create_checking(ObjRef* account_ref, char* id, ObjRef* ref)
 {
     ObjRef checking_class_ref;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CHECKING_OBJ_SIZE];
     C_struct_Checking* ptr_checking_obj = (C_struct_Checking*)kludge;
     size_t length;
 
@@ -623,8 +632,8 @@ static void get_input(char* descr, char* buffer, size_t size)
 void nwos_add_account()
 {
     char name[MAX_NAME_SIZE+2];
-    char number[MAX_NUMBER_SIZE+2];
-    char id[MAX_ID_SIZE+2];
+    char number[MAX_ACCOUNT_NUMBER_SIZE+2];
+    char id[MAX_CHECKING_ID_SIZE+2];
     ObjRef cu_ref;
     ObjRef number_ref;
     ObjRef account_ref;
@@ -706,7 +715,7 @@ void nwos_list_accounts()
 {
     ObjRef checking_class_ref;
     EveryObject class_ref_header;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CHECKING_OBJ_SIZE];
     C_struct_Checking* ptr_checking_obj = (C_struct_Checking*)kludge;
     C_struct_Account account_obj;
     C_struct_Credit_Union cu_obj;
@@ -714,7 +723,7 @@ void nwos_list_accounts()
     ReferenceList* ref_list;
     int num_refs;
     char name[MAX_NAME_SIZE+1];
-    char number[MAX_NUMBER_SIZE+1];
+    char number[MAX_ACCOUNT_NUMBER_SIZE+1];
     int i;
 
     if (!nwos_find_private_class_definition("CHECKING", &checking_class_ref))
