@@ -27,6 +27,9 @@
 --
 --
 -- $Log: import_file.c,v $
+-- Revision 1.44.2.1  2009/05/05 13:13:16  jsedwards
+-- Added 'z' to a couple of print statements to eliminate compiler warning.
+--
 -- Revision 1.44  2009/04/04 15:41:51  jsedwards
 -- Fix copyright years.  NO code changes.
 --
@@ -572,7 +575,7 @@ int main(int argc, char* argv[])
 
 		if (strlen(argv[i]) + 1 > sizeof(path))
 		{
-		    fprintf(stderr, "WARNING: the path '%s' is too long for the buffer (exceeds %d characters) - ignored.\n", argv[i], sizeof(path));
+		    fprintf(stderr, "WARNING: the path '%s' is too long for the buffer (exceeds %zd characters) - ignored.\n", argv[i], sizeof(path));
 		}
 		else if (*argv[i] == '/')
 		{
@@ -618,7 +621,7 @@ int main(int argc, char* argv[])
 	{
 	    if (strlen(argv[i]) + 1 > sizeof(path))
 	    {
-		fprintf(stderr, "WARNING: the path '%s' is too long for the buffer (exceeds %d characters) - ignored.\n", argv[i], sizeof(path));
+		fprintf(stderr, "WARNING: the path '%s' is too long for the buffer (exceeds %zd characters) - ignored.\n", argv[i], sizeof(path));
 	    }
 	    else if (*argv[i] == '/')
 	    {
