@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2004-2008  QRW Software
+--                 Copyright (C) 2004-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,20 @@
 --
 --
 -- $Log: log.c,v $
+-- Revision 1.22  2009/03/14 04:11:53  jsedwards
+-- Removed include of disk_io.h file and added include of user_config.h file.
+--
+-- Revision 1.21  2009/03/13 12:45:40  jsedwards
+-- Removed include of objectify.h file and added includes for log.h and
+-- strlcxx.h files.
+--
+-- Revision 1.20  2009/03/08 19:11:31  jsedwards
+-- Moved strlcat function to new strlcat.c file and strlcpy function to new
+-- strlcpy.c file.
+--
+-- Revision 1.19  2009/03/08 00:41:36  jsedwards
+-- Changed include objectify_private.h to disk_io.h.
+--
 -- Revision 1.18  2008/12/27 15:00:29  jsedwards
 -- Merged from alpha_29_5_branch back into main trunk.
 --
@@ -113,8 +127,9 @@
 #include <time.h>
 #include <unistd.h>
 
-#include "objectify.h" /* include this for config.h the log file path and because these functions prototypes are there */
-#include "objectify_private.h"  /* include this to get the nwos_get_log_file_path function */
+#include "log.h"
+#include "strlcxx.h"           /* in case strlcpy and strlcat are not provided by the system */
+#include "user_config.h"
 
 
 static bool log_disabled = false;
@@ -390,86 +405,3 @@ void nwos_log_sha512sum(const char* file_name, uint8 sha512_digest[SHA512_DIGEST
 }
 
 
-
-/* since neither Linux or GNU seem to have these functions */
-
-/* From the OpenBSD man page:                                       */
-/*                                                                  */
-/* The strlcpy() function copies up to size - 1 characters from the */
-/* NUL-terminated string src to dst, NUL-terminating the result.    */
-
-#ifndef HAVE_STRLCPY
-size_t strlcpy(char* dst, const char* src, size_t size)
-{
-    int i;
-
-    assert(size > 0);
-
-    for (i = 0; src[i] != '\0'; i++)
-    {
-	if (i < size)
-	{
-	    dst[i] = src[i];
-	}
-    }
-
-    if (i < size)
-    {
-	dst[i] = src[i];
-    }
-    else
-    {
-	dst[size-1] = src[i];
-    }
-
-    return i;
-}
-#endif
-
-
-/* From the OpenBSD man page:                                                        */
-/*                                                                                   */
-/* The strlcat() function appends the NUL-terminated string src to the end of dst.   */
-/* It will append at most size - strlen(dst) - 1 bytes, NUL-terminating the result.  */
-
-#ifndef HAVE_STRLCAT
-size_t strlcat(char* dst, const char* src, size_t size)
-{
-    int i, j;
-
-    assert(size > 0);
-
-    /* find the end of the destination string */
-    /* if we don't find the null before size, don't write a zero */
-    for (i = 0; dst[i] != '\0'; i++)
-    {
-	if (i >= size)
-	{
-	    return size + 1 + strlen(src);
-	}
-    }
-
-    for (j = 0; src[j] != '\0'; j++)
-    {
-	if (i < size)
-	{
-	    dst[i] = src[j];
-	}
-	i++;
-    }
-
-    if (i < size)
-    {
-	dst[i] = src[j];
-    }
-    else
-    {
-	dst[size-1] = src[j];
-    }
-
-    return i;
-}
-
-#endif
-
-
