@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2005-2008  QRW Software
+--                 Copyright (C) 2005-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,10 @@
 --
 --
 -- $Log: person.c,v $
+-- Revision 1.27  2009/03/07 15:09:02  jsedwards
+-- Removed include of objectify_private.h and changed to call
+-- nwos_generate_new_id instead of nwos_generate_new_completely_random_id.
+--
 -- Revision 1.26  2008/12/27 15:00:29  jsedwards
 -- Merged from alpha_29_5_branch back into main trunk.
 --
@@ -212,7 +216,6 @@
 #include <string.h>
 
 #include "objectify.h"
-#include "objectify_private.h"
 #include "crc32.h"
 
 #define MAX_NAME_SIZE 64
@@ -333,7 +336,7 @@ void nwos_find_or_create_private_gender(char* gender, ObjRef* ref)
 
 	assert(nwos_read_object_from_disk(&public_gender_ref, &gender_obj, sizeof(gender_obj)));
 
-	nwos_generate_new_completely_random_id(ref);
+	nwos_generate_new_id(ref);
 
 	snprintf(msg, sizeof(msg), "clone_gender(%02x%02x%02x%02x) -> %02x%02x%02x%02x\n",
 		 public_gender_ref.id[0], public_gender_ref.id[1], public_gender_ref.id[2], public_gender_ref.id[3],
