@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2006-2008  QRW Software
+--                 Copyright (C) 2006-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,25 @@
 --
 --
 -- $Log: prep_disk.c,v $
+-- Revision 1.68  2009/03/14 23:01:54  jsedwards
+-- Added include of the objectify.h file to define nwos_create_root.
+--
+-- Revision 1.67  2009/03/14 11:46:08  jsedwards
+-- Added include of user_config.h file.
+--
+-- Revision 1.66  2009/03/13 12:50:17  jsedwards
+-- Added includes for config.h and log.h files.
+--
+-- Revision 1.65  2009/03/08 00:06:18  jsedwards
+-- Changed include objectify_private.h to disk_io.h.
+--
+-- Revision 1.64  2009/03/03 03:47:24  jsedwards
+-- Deleted write_chunks function and changed main to just write the one chunk.
+--
+-- Revision 1.63  2009/02/26 16:06:33  jsedwards
+-- Feature Request #1873009 - Change so that it no longer sets the size of the
+-- archive if it is a file.
+--
 -- Revision 1.62  2008/09/06 15:34:23  jsedwards
 -- Changed to use TEST_ENVIRONMENT_VARIABLE.
 --
@@ -283,7 +302,11 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#include "objectify_private.h"
+#include "config.h"
+#include "disk_io.h"
+#include "log.h"
+#include "objectify.h"     /* define nwos_create_root */
+#include "user_config.h"
 
 
 
@@ -357,26 +380,11 @@ unsigned max_blocks_on_device(const char* path)
 /* depending upon if writing to a file or device.   */
 /****************************************************/
 
-void print_usage(char* name, bool specify_private_size)
+void print_usage(char* name)
 {
-    assert((CHUNK_SIZE % 1048576) == 0);  /* chunks must be a multiple of 1M */
+    fprintf(stderr, "usage: %s [--no-private]\n\n", name);
 
-    if (specify_private_size == false)
-    {
-	fprintf(stderr, "usage: %s [--no-private]\n\n", name);
-    }
-    else
-    {
-	fprintf(stderr, "usage: %s [--no-private] size\n\n", name);
-    }
-
-    fprintf(stderr, "  --no-private: don't create the initial private blocks (if importing old data)\n");
-
-    if (specify_private_size == true)
-    {
-	fprintf(stderr, "  size can be specified in %dM chunks, megabytes 'M', or gigabytes 'G'.\n", CHUNK_SIZE / 1048576);
-	fprintf(stderr, "  it must be a multiple of %dM.\n\n", CHUNK_SIZE / 1048576);
-    }
+    fprintf(stderr, "  --no-private: don't create the initial private blocks (if importing old data)\n\n");
 }
 
 
@@ -401,7 +409,7 @@ void agree_no_warranty()
     fprintf(stderr, "\n");
     fprintf(stderr, "Objectify version %s\n", PACKAGE_VERSION);
     fprintf(stderr, "\n");
-    fprintf(stderr, "Copyright (C) 2005-2008  J. Scott Edwards - QRW Software\n");
+    fprintf(stderr, "Copyright (C) 2004-2009  J. Scott Edwards - QRW Software\n");
     fprintf(stderr, "\n");
     fprintf(stderr, "This software comes with ABSOLUTELY NO WARRANTY; THE ENTIRE RISK AS TO THE\n");
     fprintf(stderr, "QUALITY AND PERFORMANCE OF THIS PROGRAM IS WITH YOU.  For details read the\n");
@@ -464,120 +472,6 @@ void understand_security()
 }
 
 
-/********************************************/
-/* Convert size string to number of blocks. */
-/* Must be a multiple of chunk_size.        */
-/********************************************/
-
-#define SIZE_ERROR 0xffffffff      /* return value if error occurred */
-
-uint32 convert_size(char* size)
-{
-    char* p;
-    uint32 result = 0;
-
-    assert(strlen(size) > 0);   /* bug if called with empty string */
-
-    for (p = size; isdigit(*p); p++)
-    {
-	result = result * 10 + (*p - '0');
-    }
-
-    if (toupper(*p) == 'M')
-    {
-	p++;   /* after this point we want the value in megabytes so just ignore it */
-    }
-    else if (toupper(*p) == 'G')
-    {
-	result = result * 1024;    /* change gigabytes to megabytes */
-	p++;
-    }
-    else
-    {
-	result = result * (CHUNK_SIZE / 1048576);  /* change chunks to megabytes */
-	p++;
-    }
-
-    /* at this point the result in in megabytes */
-
-    if (!isdigit(*size) || *p != 0)
-    {
-	fprintf(stderr, "Invalid size: %s\n", size);
-	return SIZE_ERROR;
-    }
-
-    if (result == 0 || (result % (CHUNK_SIZE / 1048576)) != 0)
-    {
-	fprintf(stderr, "Size must be a multiple of: %dM\n", CHUNK_SIZE / 1048576);
-	return SIZE_ERROR;
-    }
-
-    if (result < 2 * CHUNK_SIZE / 1048576)
-    {
-	fprintf(stderr, "Size must be equal to, or larger than %dM\n", 2 * CHUNK_SIZE / 1048576);
-	return SIZE_ERROR;
-    }
-
-    if (result > 1048576)
-    {
-	fprintf(stderr, "Size must be less than a 1024 gigabytes\n");
-	return SIZE_ERROR;
-    }
-
-    return result * (1048576 / FILE_BLOCK_SIZE);   /* convert megabytes to blocks */
-}
-
-
-/********************************************************************/
-/* Write the given number of chunks to the device or file.          */
-/* If num_chunks == 0 it means write until EOF.  Returns the number */
-/* blocks written (NOT chunks) because the last may not be even.    */
-/********************************************************************/
-
-uint32 write_chunks(int fd, uint8* chunk, uint32 num_chunks)
-{
-    size_t bytes_written;
-    uint32 blocks = 0;
-
-    nwos_start_progress_bar();
-
-    errno = 0;
-
-    while (num_chunks == 0 || blocks < (num_chunks * BLOCKS_IN_CHUNK))
-    {
-	nwos_update_progress_bar((float)blocks / (float)(num_chunks * BLOCKS_IN_CHUNK));
-
-	bytes_written = write(fd, chunk, CHUNK_SIZE);
-
-	if (bytes_written < 0) break;    /* exit if error occurred */
-
-	if (bytes_written % 512 != 0)
-	{
-	    fprintf(stderr, "bytes written not a multiple of 512: %zd\n", bytes_written);
-	    close(fd);
-	    exit(1);
-	}
-
-	blocks += bytes_written / 256;
-
-	if (bytes_written < CHUNK_SIZE) break;
-    }
-
-    if (errno != 0)
-    {
-	printf("\n");  /* don't finish progress bar */
-	fflush(stdout);
-
-	perror("after last write");
-	exit(1);
-    }
-
-    nwos_finish_progress_bar();
-
-    return blocks;
-}
-
-
 /***************************************************************************/
 /* Program to prepare a disk or file for NWOS storage.                     */
 /* Now there is a bit map of used blocks as the first block in every chunk */
@@ -591,14 +485,12 @@ int main(int argc, char* argv[])
     struct flock lock;
     uint8 *chunk;
     char answer[8];
-    int arg_index = 1;
     bool is_file = false;
     bool do_private_blocks = true;
 
     uint32 total_blocks;
     uint32 reserved_private_blocks;
     uint32 blocks = 0;
-    uint32 blocks_written;
     uint32 num_chunks;
     Disk_Header disk_header;
     char msg[128];
@@ -645,39 +537,28 @@ int main(int argc, char* argv[])
 	}
     }
 
-    if (argc > 1 && *argv[arg_index] == '-')   /* option specified */
+    if (argc > 1)   /* option specified */
     {
-	if (strcmp(argv[arg_index], "--no-private") == 0)
+	if (argc == 2)
 	{
-	    do_private_blocks = false;
+	    if (strcmp(argv[1], "--no-private") == 0)
+	    {
+		do_private_blocks = false;
+	    }
+	    else
+	    {
+		if (*argv[1] == '-')
+		{
+		    fprintf(stderr, "\nunknown option: %s\n\n", argv[1]);
+		}
+
+		print_usage(argv[0]);
+		exit(1);
+	    }
 	}
 	else
 	{
-	    fprintf(stderr, "\nunknown option: %s\n\n", argv[arg_index]);
-	    print_usage(argv[0], is_file);
-	    exit(1);
-	}
-
-
-	arg_index++;
-    }
-
-
-    /* must have 0 or 1 arguments */
-
-    if (is_file)
-    {
-	if (argc - arg_index != 1)
-	{
-	    print_usage(argv[0], true);
-	    exit(1);
-	}
-    }
-    else
-    {
-	if (argc - arg_index != 0)
-	{
-	    print_usage(argv[0], false);
+	    print_usage(argv[0]);
 	    exit(1);
 	}
     }
@@ -697,14 +578,7 @@ int main(int argc, char* argv[])
     }
     else
     {
-	/* use one chunk for header and block map */
-	total_blocks = convert_size(argv[arg_index]);
-
-	if (total_blocks == 0 || total_blocks == SIZE_ERROR)
-	{
-	    print_usage(argv[0], is_file);
-	    exit(1);
-	}
+	total_blocks = 2 * BLOCKS_IN_CHUNK;	     /* start with enough space for the header and one private chunk */
     }
 
     if (getenv(TEST_ENVIRONMENT_VARIABLE) == NULL)
@@ -820,16 +694,12 @@ int main(int argc, char* argv[])
 	exit(1);
     }
 
-
     /*************************************/
     /* write private portion of the disk */
     /*************************************/
 
     if (is_file)
     {
-	printf("Writing private chunks...\n");
-	fflush(stdout);
-
 	memset(chunk, 0, CHUNK_SIZE);
 
 	/* private blocks have bit maps so mark off 32 bits for the bit map itself */
@@ -838,20 +708,11 @@ int main(int argc, char* argv[])
 	chunk[2] = 0xff;
 	chunk[3] = 0xff;
 
-	blocks_written = write_chunks(obj_fd, chunk, reserved_private_blocks / BLOCKS_IN_CHUNK);
-
-	if (blocks_written < reserved_private_blocks)
+	if (write(obj_fd, chunk, CHUNK_SIZE) != CHUNK_SIZE)
 	{
-	    fprintf(stderr, "Error: not enough space for private chunks\n");
-	    close(obj_fd);
+	    perror(private_path);
 	    exit(1);
 	}
-
-	blocks += blocks_written;
-	printf("blocks: %u  blocks_written: %u  reserved_private_blocks: %u\n", 
-	       blocks, blocks_written, reserved_private_blocks);
-
-	assert(blocks == reserved_private_blocks + BLOCKS_IN_CHUNK);
     }
 
     if (close(obj_fd) != 0)
@@ -860,6 +721,8 @@ int main(int argc, char* argv[])
 	exit(1);
     }
 
+    free(chunk);
+
     printf("Total chunks: %u\n", num_chunks);
 
 
