@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2004-2008  QRW Software
+--                 Copyright (C) 2004-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,16 @@
 --
 --
 -- $Log: security.c,v $
+-- Revision 1.25  2009/03/14 19:08:10  jsedwards
+-- Moved security related variables and functions from objectify.c file.
+--
+-- Revision 1.24  2009/03/13 13:14:57  jsedwards
+-- Removed include of objectify.h file and added includes for strlcxx.h and
+-- types.h files.
+--
+-- Revision 1.23  2009/03/07 20:17:19  jsedwards
+-- Removed #include of objectify_private.h, not needed.
+--
 -- Revision 1.22  2008/12/27 15:00:29  jsedwards
 -- Merged from alpha_29_5_branch back into main trunk.
 --
@@ -126,14 +136,18 @@
 */
 
 #include <assert.h>
+#include <openssl/blowfish.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <termios.h>
 #include <unistd.h>
+
 #include "crc32.h"
-#include "objectify.h"
-#include "objectify_private.h"
+#include "disk_io.h"           /* define FILE_BLOCK_SIZE and read and write block functions */
+#include "security.h"
+#include "strlcxx.h"           /* in case strlcpy and strlcat are not provided by the system */
+#include "types.h"
 
 #include "gnu/md5.h"
 #include "gnu/sha1.h"
@@ -146,8 +160,20 @@
 #define MULTIPLIER 3141592621U
 #define ADDEND     101U
 
+#define NUM_STORED_SEQ 4096     /* number of sequence tables that are stored, 4096 = 1 MB worth and uses 1 MB worth of RAM */
 
-uint32 nwos_next_sequence(uint32* linear, uint32* serial)
+
+#ifndef PUBLIC_MODE
+static uint32 linear_after_first;
+static uint32 serial_after_first;
+
+static uint8  nwos_random_sequence[NUM_STORED_SEQ][FILE_BLOCK_SIZE];     /* this will only work for blocks <= 256 bytes */
+
+static BF_KEY blowfish_key;
+#endif
+
+
+static uint32 nwos_next_sequence(uint32* linear, uint32* serial)
 {
     uint32 feedback;
 
@@ -534,6 +560,239 @@ void nwos_get_key_from_password(uint8 key[], size_t key_size)
 
 
 
+/**********************/
+/* Sequence generator */
+/**********************/
+
+#ifndef PUBLIC_MODE
+static void generate_sequence_table(uint32* linear, uint32* serial, uint8 table[FILE_BLOCK_SIZE])
+{
+    int i;
+    uint8 j;
+    uint8 filled[FILE_BLOCK_SIZE];    /* remember which slots are already filled */
+
+    /* mark all slots as empty */
+    for (i = 0; i < FILE_BLOCK_SIZE; i++) filled[i] = 0;
+
+    /* then mark the first 8 as used */
+    for (i = 0; i < 8; i++) filled[i] = 1;
+
+    /* start at 0 because it is used already, so while loop will fail the first time. */
+    j = 0;
+    assert(filled[j] != 0);
+
+    for (i = 8; i < FILE_BLOCK_SIZE; i++)
+    {
+	/* find where the next byte is stored */
+	while(filled[j] != 0) j = nwos_next_sequence(linear, serial) % FILE_BLOCK_SIZE;
+	table[i] = j;   /* store it in the table */
+	filled[j] = 1;            /* mark it as used */
+    }
+}
+#endif
+
+
+#ifndef PUBLIC_MODE
+void nwos_setup_from_big_key(uint8 big_key[16 + 8 + 4], ObjRef* root_object_ref)
+{
+    int i;
+    int j;
+    int k;
+    int tries;
+
+    BF_set_key(&blowfish_key, 16, big_key);
+
+    linear_after_first = ((uint32)big_key[16] << 24) | ((uint32)big_key[17] << 16) | ((uint32)big_key[18] << 8) | (uint32)big_key[19];
+    serial_after_first = ((uint32)big_key[24] << 24) | ((uint32)big_key[25] << 16) | ((uint32)big_key[26] << 8) | (uint32)big_key[27];
+
+    /* Create all of the sequence tables from the linear and serial parameters */
+    for (i = 0; i < NUM_STORED_SEQ; i++)
+    {
+	tries = 0;
+
+	do
+	{
+	    tries++;
+
+	    assert(tries < 4);
+
+	    generate_sequence_table(&linear_after_first, &serial_after_first, nwos_random_sequence[i]);
+
+	    for (j = 0; j < i; j++)
+	    {
+		for (k = 8; k < FILE_BLOCK_SIZE; k++) if (nwos_random_sequence[i][k] != nwos_random_sequence[j][k]) break;
+
+		if (k == FILE_BLOCK_SIZE) break;
+	    }
+	}
+	while (j < i);   /* if j is less than i it means one of the tables matched and needs to be regenerated */
+    }
+
+    assert(sizeof(ObjRef) == 4);   /* the following code assumes 4 byte IDs */
+
+    memcpy(root_object_ref->id, big_key+20, 4);
+}
+#endif
+
+
+bool nwos_read_block_from_disk_and_old_decrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], int seq)
+{
+    uint8 encrypted[FILE_BLOCK_SIZE];
+#ifndef PUBLIC_MODE
+    uint8 scrambled[FILE_BLOCK_SIZE];
+    int i;
+    int j;
+#endif
+    bool result = false;
+
+    assert(!is_void_reference(ref));
+
+    if (nwos_read_block(ref, encrypted))
+    {
+#ifdef PUBLIC_MODE
+	memcpy(object, encrypted, size);
+#else
+
+#ifdef DISABLE_SECURITY_FEATURES
+	if (true)
+#else
+	if (nwos_reference_type(ref) == Public_Reference)
+#endif
+	{
+	    memcpy(object, encrypted, size);    /* just copy the buffer into the object */
+	}
+	else
+	{
+	    /* copy the first 8 bytes directly, not encrypted */
+	    memcpy(object, encrypted, 8);
+
+	    /* decrypt the remaining bytes */
+	    BF_cbc_encrypt((encrypted + 8), (scrambled + 8), (FILE_BLOCK_SIZE - 8), &blowfish_key, ivec, BF_DECRYPT);
+
+	    assert(size <= FILE_BLOCK_SIZE);
+
+	    for (i = 8; i < size; i++)
+	    {
+		j = nwos_random_sequence[seq % NUM_STORED_SEQ][i];    /* find where the next byte is stored */
+		((uint8*)object)[i] = scrambled[j];    /* get this byte from there */
+	    }
+	}
+
+#endif
+	result = true;
+    }
+
+    return result;
+}
+
+
+bool nwos_read_block_from_disk_and_decrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], int seq)
+{
+    uint8 scrambled[FILE_BLOCK_SIZE];
+#ifndef PUBLIC_MODE
+    uint8 encrypted[FILE_BLOCK_SIZE];
+    uint8 decrypted[FILE_BLOCK_SIZE];
+    int i;
+    int j;
+#endif
+    bool result = false;
+
+    assert(!is_void_reference(ref));
+
+    if (nwos_read_block(ref, scrambled))
+    {
+#ifdef PUBLIC_MODE
+	memcpy(object, scrambled, size);
+#else
+
+#ifdef DISABLE_SECURITY_FEATURES
+	if (true)
+#else
+	if (nwos_reference_type(ref) == Public_Reference)
+#endif
+	{
+	    memcpy(object, scrambled, size);    /* just copy the buffer into the object */
+	}
+	else
+	{
+	    /* copy the first 8 bytes directly, not encrypted */
+	    memcpy(object, scrambled, 8);
+
+	    /* descramble */
+	    for (i = 8; i < FILE_BLOCK_SIZE; i++)
+	    {
+		j = nwos_random_sequence[seq % NUM_STORED_SEQ][i];    /* find where the next byte is stored */
+		encrypted[i] = scrambled[j];    /* get this byte from there */
+	    }
+
+	    assert(size <= FILE_BLOCK_SIZE);
+
+	    /* decrypt */
+	    BF_cbc_encrypt((encrypted + 8), (decrypted + 8), (FILE_BLOCK_SIZE - 8), &blowfish_key, ivec, BF_DECRYPT);
+
+	    memcpy((object + 8), (decrypted + 8), (size - 8));
+	}
+
+#endif
+	result = true;
+    }
+
+    return result;
+}
+
+
+void nwos_write_block_to_disk_and_encrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], int seq)
+{
+    uint8 scrambled[FILE_BLOCK_SIZE];
+#ifndef PUBLIC_MODE
+    uint8 decrypted[FILE_BLOCK_SIZE];
+    uint8 encrypted[FILE_BLOCK_SIZE];
+    int i;
+    int j;
+#endif
+
+    assert(!is_void_reference(ref));
+    assert(size <= FILE_BLOCK_SIZE);
+
+#ifdef PUBLIC_MODE
+    memset(scrambled, 0, FILE_BLOCK_SIZE);
+    memcpy(scrambled, object, size);
+#else
+
+#ifdef DISABLE_SECURITY_FEATURES    /* always do the unencryped code */
+    if (true)
+#else
+    if (nwos_reference_type(ref) == Public_Reference)
+#endif
+    {
+	memset(scrambled, 0, FILE_BLOCK_SIZE);    /* just copy the object into the buffer */
+	memcpy(scrambled, object, size);
+    }
+    else
+    {
+	/* copy the first 8 bytes straight across */
+	memcpy(scrambled, object, 8);
+
+	memcpy((decrypted + 8), (object + 8), size - 8);
+
+	/* fill any empty slots with random junk */
+	for (i = size; i < FILE_BLOCK_SIZE; i++) decrypted[i] = random();
+
+	/* and encrypt the remainder */
+	BF_cbc_encrypt((decrypted + 8), (encrypted + 8), (FILE_BLOCK_SIZE - 8), &blowfish_key, ivec, BF_ENCRYPT);
+
+	for (i = 8; i < FILE_BLOCK_SIZE; i++)
+	{
+	    /* find where the next byte is stored */
+	    j = nwos_random_sequence[seq % NUM_STORED_SEQ][i];    /* find where the next byte is stored */
+	    scrambled[j] = encrypted[i];    /* save this byte there */
+	}
+    }
+#endif
+
+    nwos_write_block(ref, scrambled);
+}
+
 
 #if 0
 int main(int argc, char* argv[])
@@ -569,3 +828,4 @@ int main(int argc, char* argv[])
 }
 #endif
 
+
