@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2006-2008  QRW Software
+--                 Copyright (C) 2006-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,12 @@
 --
 --
 -- $Log: update_files_0028.c,v $
+-- Revision 1.9  2009/03/10 10:30:27  jsedwards
+-- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
+--
+-- Revision 1.8  2009/03/08 00:37:42  jsedwards
+-- Changed include objectify_private.h to disk_io.h.
+--
 -- Revision 1.7  2008/09/01 03:13:45  jsedwards
 -- Change for new nwos_initialize_objectify calling convention (doesn't pass
 -- back root_object_reference anymore) and removed call to nwos_set_root_object
@@ -64,7 +70,7 @@
 #include <string.h>
 
 #include "crc32.h"
-#include "objectify_private.h"   /* do private so that nwos_get_public_objects_path is defined */
+#include "disk_io.h"       /* define nwos_get_public_objects_path */
 #include "time_stamp.h"
 
 
@@ -110,7 +116,7 @@ int main(int argc, char* argv[])
     C_struct_Path_And_File_Association assoc_obj;
     C_struct_Path_And_File_Association prev_assoc_obj;
     C_struct_Path_And_File_Association next_assoc_obj;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_PATH_OBJ_SIZE];
     C_struct_File_Path* ptr_path_obj = (C_struct_File_Path*)kludge;
     C_struct_File file_obj;
     C_struct_File prev_file_obj;
