@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2005-2008  QRW Software
+--                 Copyright (C) 2005-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,13 @@
 --
 --
 -- $Log: word.c,v $
+-- Revision 1.27  2009/03/14 14:33:39  jsedwards
+-- Changed to read language object to verify it exists instead of calling
+-- nwos_object_exists function which no longer exists.
+--
+-- Revision 1.26  2009/03/07 20:17:19  jsedwards
+-- Removed #include of objectify_private.h, not needed.
+--
 -- Revision 1.25  2008/09/01 00:10:56  jsedwards
 -- Fix copyright year.  NO code changes.
 --
@@ -130,13 +137,13 @@
 
 #include "crc32.h"
 #include "objectify.h"
-#include "objectify_private.h"
 
 
 
 bool nwos_find_word(char* word, ObjRef* thing_class, ObjRef* lang, ObjRef* ref)
 {
     C_struct_Word word_obj;
+    C_struct_Language lang_obj;
     EveryObject spelling_header;
     EveryObject thing_header;
     ObjRef word_class_ref;
@@ -147,7 +154,7 @@ bool nwos_find_word(char* word, ObjRef* thing_class, ObjRef* lang, ObjRef* ref)
     int i;
     bool result = false;
 
-    assert(nwos_object_exists(lang));
+    assert(nwos_read_object_from_disk(lang, &lang_obj, sizeof(lang_obj)));   /* read the language object just to verify it exists */
 
     assert(nwos_find_public_class_definition("WORD", &word_class_ref));
 
@@ -194,12 +201,13 @@ bool nwos_find_word(char* word, ObjRef* thing_class, ObjRef* lang, ObjRef* ref)
 ObjCreateResult nwos_create_word(char* word, ObjRef* thing, ObjRef* lang, ObjRef* ref)
 {
     C_struct_Word word_obj;
+    C_struct_Language lang_obj;
     EveryObject thing_header;
     ObjRef word_class_ref;
     ObjRef spelling_ref;
     ObjCreateResult result = CREATED_NEW;
 
-    assert(nwos_object_exists(lang));
+    assert(nwos_read_object_from_disk(lang, &lang_obj, sizeof(lang_obj)));   /* read the language object just to verify it exists */
 
     /* for now all words must be public */
 
